@@ -4,7 +4,7 @@ import time
 import uuid
 
 from datetime import datetime
-from typing import Any
+from typing import Any, Callable
 
 import paho.mqtt.client as mqtt
 
@@ -86,6 +86,7 @@ class InelsMqtt:
         _t = config.get(MQTT_TIMEOUT)
         self.__timeout = _t if _t is not None else __DISCOVERY_TIMEOUT__
 
+        self.__data_changed = dict[str, Callable[[Any], Any]]()
         self.__try_connect = False
         self.__message_readed = False
         self.__messages = dict[str, str]()
@@ -130,6 +131,12 @@ class InelsMqtt:
 
         return self.__is_available
 
+    def append_data_change_listener(
+        self, topic: str, fnc: Callable[[Any], Any]
+    ) -> None:
+        """Append new item into the datachange listener."""
+        self.__data_changed[topic] = fnc
+
     def __connect(self) -> None:
         """Create connection and register callback function to neccessary
         purposes.
@@ -338,6 +345,10 @@ class InelsMqtt:
         if device_type in DEVICE_TYPE_DICT:
             self.__messages[msg.topic] = msg.payload
 
+        if not self.__data_changed and msg.topic in self.__data_changed:
+            # This pass data change directely into the device.
+            self.__data_changed[msg.topic](msg.payload)
+
     def __on_subscribe(
         self,
         client: mqtt.Client,  # pylint: disable=unused-argument
