@@ -70,6 +70,7 @@ class Device(object):
 
         # subscribe availability
         self.__mqtt.subscribe(self.__connected_topic, 0, None, None)
+        self.__mqtt.append_data_change_listener(self.__state_topic, self.__update_value)
 
     @property
     def unique_id(self) -> str:
@@ -170,13 +171,12 @@ class Device(object):
         """Get values of inels and ha type."""
         return self.__values
 
-    def get_value(self) -> DeviceValue:
-        """Get value from inels
+    def __update_value(self, new_value: Any) -> None:
+        """Update value after broker change it."""
+        self.__get_value(new_value)
 
-        Returns:
-            Any: DeviceValue
-        """
-        val = self.__mqtt.messages().get(self.state_topic)
+    def __get_value(self, val: Any) -> DeviceValue:
+        """Get value and transform into the DeviceValue."""
         dev_value = DeviceValue(
             self.__device_type,
             self.__inels_type,
@@ -188,6 +188,15 @@ class Device(object):
 
         return dev_value
 
+    def get_value(self) -> DeviceValue:
+        """Get value from inels
+
+        Returns:
+            Any: DeviceValue
+        """
+        val = self.__mqtt.messages().get(self.state_topic)
+        return self.__get_value(val)
+
     def set_ha_value(self, value: Any) -> bool:
         """Set HA value. Will automaticaly convert HA value
         into the inels value format.
