@@ -15,6 +15,17 @@ class InelsDiscovery(object):
         """Initilize inels mqtt discovery"""
         self.__mqtt = mqtt
         self.__devices: list[Device] = []
+        self.__coordinators: list[str] = []
+        self.__coordinators_with_devices: dict[str, list[Device]] = {}
+
+    @property
+    def coordinators(self) -> list[str]:
+        """Coordinators list
+
+        Returns:
+            _type_: list of coordinator serial numbers
+        """
+        return self.__coordinators
 
     @property
     def devices(self) -> list[Device]:
@@ -25,15 +36,21 @@ class InelsDiscovery(object):
         """
         return self.__devices
 
-    def discovery(self) -> list[Device]:
+    def discovery(self) -> dict[str, list[Device]]:
         """Discover and create device list
 
         Returns:
             list[Device]: List of Device object
         """
         devs = self.__mqtt.discovery_all()
+        self.__devices = [Device(self.__mqtt, item) for item in devs]
 
-        self.__devices = [Device(self.__mqtt, item, devs[item]) for item in devs]
+        for item in self.__devices:
+            if item.parent_id not in self.__coordinators:
+                self.__coordinators.append(item.parent_id)
+                self.__coordinators_with_devices[item.parent_id] = []
+
+            self.__coordinators_with_devices[item.parent_id].append(item)
 
         _LOGGER.info("Discovered %s devices", len(self.__devices))
 
